@@ -380,8 +380,22 @@ setMethod(f = "getCapabilities", signature = signature(sos = "SOS_1.0.0"),
 #
 .describeSensor_1.0.0 <- function(sos, procedure, outputFormat, verbose,
 		inspect, saveOriginal) {
-	if(verbose) {
-		cat("[.describeSensor_1.0.0] ", procedure, "@", sos@url, "\n")
+	if(verbose) cat("[.describeSensor_1.0.0] ", procedure, "@", sos@url, "\n")
+	
+	# check if multiple sensors
+	if(length(procedure) > 1) {
+		if(verbose) cat("[.describeSensor_1.0.0] multiple sensors: ", procedure,
+					"\n")
+		
+		.descriptions <- list()
+		for (p in procedure) {
+			.description <- .describeSensor_1.0.0(sos = sos, procedure = p,
+					outputFormat = outputFormat, verbose = verbose,
+					inspect = inspect, saveOriginal = saveOriginal)
+			.descriptions <- c(.descriptions, .description)
+		}
+		
+		return(.descriptions)
 	}
 	
 	.ds <- SosDescribeSensor(service = sosService, version = sos@version,
@@ -450,9 +464,10 @@ setMethod(f = "describeSensor",
 		signature = signature(sos = "SOS_1.0.0", procedure  = "character"), 
 		def = function(sos, procedure, outputFormat, verbose, inspect,
 				saveOriginal) {
-			return(.describeSensor_1.0.0(sos = sos, procedure = procedure,
-							outputFormat = outputFormat, verbose = verbose,
-							inspect = inspect, saveOriginal = saveOriginal))
+			.result <- .describeSensor_1.0.0(sos = sos, procedure = procedure,
+					outputFormat = outputFormat, verbose = verbose,
+					inspect = inspect, saveOriginal = saveOriginal)
+			return(.result)
 		}
 )
 
@@ -613,25 +628,53 @@ setMethod(f = "getObservationById",
 	if(verbose) cat("[.getObservation_1.0.0] Content-Type:", .contentType, "\n")
 	
 	if(isXMLString(.responseString)) {
-		if(verbose) cat("[.getObservation_1.0.0] Got XML string as response.\n")
+		if(verbose) cat("[.getObservation_1.0.0] Got XML string as response",
+					"(based on isXMLString()).\n")
 		
+		.hasSubtype <- FALSE
+		.contentSubtype <- NA
 		if(length(.contentType) < 1) {
 			if(verbose) cat("[.getObservation_1.0.0] No content type!",
 						"Falling back to '", mimeTypeXML, "'\n")
 			.contentType <- mimeTypeXML
 		}
+		else if(length(.contentType) > 1) {
+			# check if subtype is present or take just the first
+			.subtypeIdx <- which(names(.contentType) == "subtype")
+			if(.subtypeIdx > 0) {
+				.hasSubtype <- TRUE
+				.contentSubtype <- .contentType[[.subtypeIdx]]
+				if(verbose) cat("[.getObservation_1.0.0] Found mime subtype: ",
+							toString(.contentSubtype), "'\n")
+			}
+			else if(verbose) cat(
+						"[.getObservation_1.0.0] More than one content type, ",
+								"no subtype detected : '",
+								toString(.contentType),
+								"'\n\tUsing the first one: '",
+								.contentType[[1]], "'\n")
+			.contentType <- .contentType[[1]]
+		}
 
 		.response <- xmlParseDoc(.responseString, asText = TRUE)
 		if(verbose || inspect) {
 			cat("[.getObservation_1.0.0] RESPONSE DOC:\n")
 			print(.response)
 		}
-		
 		# select the parser and file ending based on the mime type FIRST
 		.fileEnding <- ".xml"
 		if(.contentType == mimeTypeXML) {
-			if(verbose) cat("[.getObservation_1.0.0] Got pure XML according to mime type.\n")
-			.parserName <- mimeTypeXML
+			if(.hasSubtype && .contentSubtype == mimeSubtypeOM) {
+				if(verbose)
+					cat("[.getObservation_1.0.0] Got OM according to mime type.\n")
+				.parserName <- mimeTypeOM
+			}
+			else {
+				if(verbose)
+					cat("[.getObservation_1.0.0] Got pure XML according to mime type. ",
+							"Trying to parse with default parser, see SosParsingFunctions().\n")
+				.parserName <- mimeTypeXML
+			}
 		}
 		else if (.contentType == mimeTypeKML) {
 			if(verbose) cat("[.getObservation_1.0.0] Got KML according to mime type.\n")
